@@ -3,9 +3,13 @@ import os
 
 from scipy.sparse import csr_matrix
 import numpy as np
+
+from tf_geometric import SparseAdj
+
 os.environ["CUDA_VISIBLE_DEVICES"] = "6"
 
-from tf_geometric import SparseMatrix
+from tf_sparse import SparseMatrix
+
 import tensorflow as tf
 
 
@@ -17,7 +21,7 @@ edge_index = [
 
 adj = SparseMatrix(edge_index, merge=True)
 print(adj.to_dense())
-asdfasdf
+# asdfasdf
 # print(adj)
 # print("==========")
 # print(adj.to_sparse_tensor())
@@ -45,6 +49,8 @@ b = (m @ m).todense()
 print("diff")
 print(a.numpy() - b)
 
+print(adj.softmax(axis=-1).to_dense())
+
 
 
 # print("1 ======")
@@ -61,4 +67,8 @@ print(a.numpy() - b)
 # h = np.random.randn(9, 20).astype(np.float32)
 #
 # print(adj @ h)
+# print(adj.softmax(axis=-1))
+
+# adj = SparseAdj(adj.index, adj.value, adj.shape)
+
 # print(adj.softmax(axis=-1))
\ No newline at end of file
