@@ -1,7 +1,9 @@
 # coding=utf-8
 import tensorflow as tf
 
-from tf_geometric.sparse.sparse_adj import SparseAdj
+# from tf_geometric.sparse.sparse_adj import SparseAdj
+from tf_sparse import SparseMatrix
+
 from tf_geometric.utils.graph_utils import add_self_loop_edge
 import tf_sparse as tfs
 
@@ -12,7 +14,7 @@ def gat(x, edge_index,
         query_kernel, query_bias, query_activation,
         key_kernel, key_bias, key_activation,
         kernel, bias=None, activation=None, num_heads=1,
-        split_value_heads=True, drop_rate=0.0, training=False):
+        split_value_heads=True, edge_drop_rate=0.0, training=False):
     """
 
     :param x: Tensor, shape: [num_nodes, num_features], node features
@@ -29,7 +31,7 @@ def gat(x, edge_index,
     :param num_heads: Number of attention heads.
     :param split_value_heads: Boolean. If true, split V as value attention heads, and then concatenate them as output.
         Else, num_heads replicas of V are used as value attention heads, and the mean of them are used as output.
-    :param drop_rate: Dropout rate.
+    :param edge_drop_rate: Dropout rate of attention weights.
     :param training: Python boolean indicating whether the layer should behave in
         training mode (adding dropout) or in inference mode (doing nothing).
     :return: Updated node features (x), shape: [num_nodes, num_output_features]
@@ -78,9 +80,9 @@ def gat(x, edge_index,
 
     # new implementation based on SparseAdj
     num_nodes_ = num_nodes * num_heads
-    sparse_att_adj = SparseAdj(qk_edge_index_, att_score_, [num_nodes_, num_nodes_]) \
+    sparse_att_adj = SparseMatrix(qk_edge_index_, att_score_, [num_nodes_, num_nodes_]) \
         .segment_softmax(axis=-1) \
-        .dropout(drop_rate, training=training)
+        .dropout(edge_drop_rate, training=training)
 
     if split_value_heads:
         V_ = tf.concat(tf.split(V, num_heads, axis=-1), axis=0)
