@@ -1,7 +1,9 @@
 # coding=utf-8
 
 import tensorflow as tf
-from tf_geometric.sparse.sparse_adj import SparseAdj
+# from tf_geometric.sparse.sparse_adj import SparseAdj
+from tf_sparse import SparseMatrix
+
 from tf_geometric.nn.conv.gcn import gcn_norm_adj
 import tf_sparse as tfs
 
@@ -22,7 +24,7 @@ def sgc(x, edge_index, edge_weight, k, kernel, bias=None, activation=None, renor
     :return: Updated node features (x), shape: [num_nodes, num_features]
     """
     num_nodes = tfs.shape(x)[0]
-    sparse_adj = SparseAdj(edge_index, edge_weight, [num_nodes, num_nodes])
+    sparse_adj = SparseMatrix(edge_index, edge_weight, [num_nodes, num_nodes])
     normed_sparse_adj = gcn_norm_adj(sparse_adj, renorm, improved, cache)
 
     # SparseTensor is usually used for one-hot node features (For example, feature-less nodes.)
